@@ -2,35 +2,48 @@
 # Roxy AI Inspect-Server
 import os
 import sys
-from argparse import ArgumentParser
+from argparse import ArgumentParser, RawTextHelpFormatter
 from pathlib import Path
 from subprocess import call, run
 import shutil
 import colorama
 from termcolor import cprint
-
+from time import sleep
 
 # ==================================================================
 # 各種定数定義
 # ==================================================================
 SCRIPT_NAME = Path(sys.argv[0])
 SERVER_FOLDER = Path(__file__).parent.resolve()
-if os.environ.get('VIRTUAL_ENV'):
-    # Python仮想環境からの起動
+venv_path = os.environ.get('VIRTUAL_ENV')
+if venv_path:
+    import roxyai_inspect
+    module_path = Path(roxyai_inspect.__file__).absolute()
     SCRIPTS_FOLDER = Path(os.environ['VIRTUAL_ENV']) / 'Scripts'
-    WORK_FOLDER = Path(os.getcwd())
-    CHECKER_PATH = 'roxy_lic_checker.exe'
+    if Path(venv_path) in module_path.parents:
+        # 通常インストールのPython仮想環境からの起動
+        CHECKER_PATH = 'roxy_lic_info.exe'
+    else:
+        # 開発用インストール（-eオプション）のPython仮想環境からの起動
+        CHECKER_PATH = module_path.parent / 'roxy_lic_info.exe'
 else:
     # Python仮想環境外からの起動
     SCRIPTS_FOLDER = SERVER_FOLDER.parent.parent.parent / 'Scripts'
     WORK_FOLDER = SCRIPTS_FOLDER.parent.parent
-    CHECKER_PATH = SCRIPTS_FOLDER / 'roxy_lic_checker.exe'
+    CHECKER_PATH = SCRIPTS_FOLDER / 'roxy_lic_info.exe'
 VENV_ACTIVATE = SCRIPTS_FOLDER / 'activate.bat'
 INSPECT_SERVER = SERVER_FOLDER / 'inspect_server.py'
 SERVER_LICENSE = SERVER_FOLDER / 'pytransform/license.lic'
 DEFAULT_CONFIG = SERVER_FOLDER / 'config/system_config.json'
 parser = None
 
+TF_VERSION_FILE = SERVER_FOLDER.parent / 'TENSORFLOW_VERSION'
+
+if TF_VERSION_FILE.exists():
+    TF_VERSION = TF_VERSION_FILE.read_text(encoding='utf_8', errors='ignore').split('\n')[0].strip()
+else:
+    TF_VERSION = 'tf24'
+
 # デフォルトのフォルダ定義
 SAMPLE_CONFIG = SERVER_FOLDER / 'config/sample/'
 SETUP_FOLDER = {
@@ -45,8 +58,6 @@ SETUP_FOLDER = {
 SETUP_FILES = {
     # コピー先ファイル名: コピー元Pathクラス
     'サーバー設定      ': ('config/system_config.json', SAMPLE_CONFIG / 'system_config.json'),
-    '検査サーバログ設定': ('config/inspect_server_log.conf', SAMPLE_CONFIG / 'inspect_server_log.conf'),
-    '分析サーバログ設定': ('config/analyze_server_log.conf', SAMPLE_CONFIG / 'analyze_server_log.conf'),
 }
 CONFIG_PATH = Path('config/system_config.json')
 
@@ -124,7 +135,9 @@ def err_exit(message: str, errcode: int, description: str = ''):
     print()
     cprint(message, color='red')
     print(description)
+    print()
     parser.print_usage()
+    sleep(5.0)
     sys.exit(errcode)
 
 
@@ -148,13 +161,13 @@ def launch_server(config):
     try:
         call_python(INSPECT_SERVER, str(config))
     except Exception as e:
-        err_exit('Roxy AI Inspect-Server の実行に失敗しました。', 1, str(e))
+        err_exit('Roxy AI Inspect-Server の実行を中止しました。', 1, str(e))
+    sleep(5.0)
 
 
 def check_license(regfile: Path):
-    """ roxy_lic_checker.exe でライセンスファイルをチェック
+    """ roxy_lic_info.exe でライセンスファイルをチェック
     """
-    start_server = True
     if regfile:
         if not regfile.exists():
             err_exit('ライセンスファイルが見つかりません。', 3, str(regfile.resolve()))
@@ -163,79 +176,30 @@ def check_license(regfile: Path):
         print('ライセンスファイル ', end='')
         cprint(str(regfile.resolve()), color='cyan', end='')
         print(' を登録します。')
-        if SERVER_LICENSE.exists():
-            print('古いライセンスファイルに上書きで登録します。')
-            cprint('    続けるには [Y] を入力してください >>> ', 'yellow', end='')
-            answer = input('')
-            if answer in ('y', 'Y', 'yes', 'Yes', 'YES'):
-                try:
-                    SERVER_LICENSE.unlink()
-                except Exception as e:
-                    err_exit('古いライセンスファイルが削除できません。', 4, f'{SERVER_LICENSE}\n{e}')
-            else:
-                err_exit('ライセンスファイルの登録を中止します。', 0)
         try:
-            shutil.copy2(str(regfile), str(SERVER_LICENSE))
+            command = f'{CHECKER_PATH} -r -s {SERVER_LICENSE.parent} {str(regfile)}'
+            result = run(command)
+            if result.returncode == 126:
+                err_exit('ライセンスファイルの種類が異なります。', 5)
+            elif result.returncode == 127:
+                err_exit('PC識別IDが一致していません。', 5)
+            elif result.returncode == 128:
+                err_exit('ライセンス有効期間が終わっています。', 5)
+            elif result.returncode != 0:
+                err_exit('ライセンスファイルのインストールに失敗しました。', 5)
+            else:
+                print('ライセンスファイルを登録しました。')
         except Exception as e:
-            err_exit('ライセンスファイルのコピーに失敗しました。', 5, f'{regfile} -> {SERVER_LICENSE}\n{e}')
-        print('ライセンスファイルを登録しました。')
-        start_server = False
+            err_exit('ライセンスファイルのインストールに失敗しました。', 5, f'{command}\n{e}')
+        # ライセンス登録後はコマンド処理終了
+        sleep(5.0)
+        sys.exit(0)
 
-    command = f'{CHECKER_PATH} -i {SERVER_LICENSE}'
+    command = f'{CHECKER_PATH} -c -r {SERVER_LICENSE}'
+    print(command)
     result = run(command)
     if result.returncode != 0:
         err_exit('有効なライセンスファイルが登録されていません。', -1)
-    if not start_server:
-        # ライセンス登録後はコマンド処理終了
-        sys.exit(0)
-
-
-def change_tf24():
-    try:
-        # インストール状態確認
-        call_python('-m pip freeze | findstr tensorflow-gpu==2.4.0')
-        call_python('-m pip freeze | findstr tensorflow-addons==0.12.0')
-        print('\nすでに ', end='')
-        cprint('TensorFlow 2.4.0', color='yellow', end='')
-        print(' がPython仮想環境にインストールされています。')
-        exit(0)
-    except Exception:
-        pass
-    try:
-        call_python(
-            '-m pip install --upgrade tensorflow-gpu==2.4.0 '
-            'tensorflow-addons==0.12.0 cloud-tpu-client==0.10'
-        )
-    except Exception as e:
-        err_exit('TensorFlow 2.4.0 への切り替えに失敗しました。', 1, str(e))
-    print('\nPython仮想環境を ', end='')
-    cprint('TensorFlow 2.4.0', color='yellow', end='')
-    print(' に切り替えました。')
-    cprint('動作するために CUDA 11.0 と対応した cuDNN と GPUドライバがインストールされている必要があります。', color='cyan')
-
-
-def change_tf21():
-    try:
-        # インストール状態確認
-        call_python('-m pip freeze | findstr tensorflow-gpu==2.1.0')
-        call_python('-m pip freeze | findstr tensorflow-addons==0.8.3')
-        print('\nすでに ', end='')
-        cprint('TensorFlow 2.1.0', color='yellow', end='')
-        print(' がPython仮想環境にインストールされています。')
-        exit(0)
-    except Exception:
-        pass
-    try:
-        call_python(
-            '-m pip install --upgrade tensorflow-gpu==2.1.0 '
-            'tensorflow-addons==0.8.3'
-        )
-    except Exception as e:
-        err_exit('TensorFlow 2.1.0 への切り替えに失敗しました。', 1, str(e))
-    print('\nPython仮想環境を ', end='')
-    cprint('TensorFlow 2.1.0', color='yellow', end='')
-    print(' に切り替えました。')
-    cprint('動作するために CUDA 10.1 と対応した cuDNN と GPUドライバがインストールされている必要があります。', color='cyan')
 
 
 def main():
@@ -249,22 +213,31 @@ def main():
     # コマンド引数のパース
     parser = ArgumentParser(
         description="Roxy AI Inspect-Server",
-        epilog="",
+        formatter_class=RawTextHelpFormatter,
+        epilog=(
+            "TensorFlowバージョンを切り替える場合は以下の pip コマンドで更新してください。\n"
+            "  pip install --upgrade roxyai-inspect[tf21]    ← TensorFlow 2.1.0 への切り替え時\n"
+            "  pip install --upgrade roxyai-inspect[tf24]    ← TensorFlow 2.4.0 への切り替え時\n"
+        ),
     )
     parser.add_argument('-l', '--license', type=Path, help='ライセンスファイル登録')
     parser.add_argument('-s', '--setup', action='store_true', help='プロジェクトフォルダのサンプル生成')
-    parser.add_argument('-tf24', action='store_true', help='TensorFlow 2.4 環境に切り替え')
-    parser.add_argument('-tf21', action='store_true', help='TensorFlow 2.1 環境に切り替え')
     parser.add_argument('config_file', nargs='?', default=DEFAULT_CONFIG.as_posix(), help='設定ファイル')
     args = parser.parse_args()
 
-    # TensorFlow の切り替え
-    if args.tf24:
-        change_tf24()
-        exit(0)
-    if args.tf21:
-        change_tf21()
-        exit(0)
+    try:
+        import os
+        os.environ['TF_CPP_MIN_LOG_LEVEL'] = '1'
+        import tensorflow as tf
+        print('TensorFlow version check', end='')
+        print(f'\rTensorFlow: version {tf.__version__}\n')
+    except Exception:
+        message = (
+            "\nroxyai-inspect は TensorFlow のバージョンを指定してインストールしてください。\n"
+            "  pip install --upgrade roxyai-inspect[tf21]    ← TensorFlow 2.1.0 利用時\n"
+            "  pip install --upgrade roxyai-inspect[tf24]    ← TensorFlow 2.4.0 利用時\n"
+        )
+        err_exit('TensorFlowが動作しません。', 7, message)
 
     # ライセンスチェック
     check_license(args.license)
